@@ -83,7 +83,7 @@ plot_features(gffFile1, includeCounts = TRUE)
 ##=================================================================================##
 
 # get the plot in a PDF file
-outPlot1 <- file.path(dir,"treeplot_from_gff3_file.pdf")
+outPlot1 <- file.path(tempdir(),"treeplot_from_gff3_file.pdf")
 plot_features(gffFile1, outPlot1, exportFormat = "pdf", includeCounts = FALSE)
 
 
@@ -97,7 +97,7 @@ plot_features(gffFile1, outPlot1, exportFormat = "pdf", includeCounts = FALSE)
 #  library("rsvg")
 #  
 #  # get the plot in a svg file
-#  outPlot2 <- file.path(dir,"outplot_from_gff3.svg")
+#  outPlot2 <- file.path(tempdir(),"outplot_from_gff3.svg")
 #  plot_features(gffFile1, outPlot2, exportFormat = "svg", includeCounts = TRUE)
 #  
 
@@ -198,7 +198,7 @@ head(read.table(gtfFile1,sep="\t"))
 ## ----echo=TRUE, results='hide', message=FALSE, warning=FALSE------------------
 
 # convert the GTF format to GFF3 format
-gffFileConverted <- gtf_to_gff3(gtfFile1, forceOverwrite = TRUE)
+gffFileConverted <- gtf_to_gff3(gtfFile1)
 
 
 
